## CHANGELOG

### 0.10.0 - 2019-10-20

 - Add gzip upload support

 - Create background tasks feature

### 0.9.0 - 2019-10-07

 - Improve response types

 - Fix headers response

### 0.8.0 - 2019-10-07

 - Fix headers response

### 0.7.0 - 2019-10-06

 - Improve devtools

 - Improve docs

 - Refactor the entirely api

### 0.6.0 - 2019-10-04

 - Add devtools submodule

 - Refactor path decorator

 - Improve examples to use async def

 - Update public interface

 - Improve docs


### 0.5.0 (2019-09-20)

 - Improves requests/responses objects


### 0.4.1 (2019-09-19)

 - Improve docs


### 0.4.0 (2019-09-19)

 - Rename typingjson project do jsondaora


### 0.3.0 (2019-09-19)

 - Add TypedDict support

 - Rename project


### 0.2.0 (2019-09-18)

 - Refactor app and router modules


### 0.1.2 (2019-09-18)

 - Improve docs


### 0.1.1 (2019-09-18)

 - Fix docs


### 0.1.0 (2019-09-18)

 - Add initial files
